@@ -7,14 +7,18 @@
 # published by the Free Software Foundation
 
 """
-The :mod:`config <bibtexvcs.config>` module contains helpers for persisten configuration of BibTeX VCS.
+The :mod:`config <bibtexvcs.config>` module contains helpers for persisten configuration of BibTeX
+VCS.
 Currently, this allows to store VCS auth information and a default database to open at startup.
 """
 
 from __future__ import division, print_function, unicode_literals
-import configparser, io, os.path
+import configparser
+import io
+import os.path
 import atexit
 
+
 def getConfigPath():
     """Return the path of the configuration file. Defaults to ``~/.config/bibtexvcs`` on Unix,
     ``%APPDATA%/bibtexvcs`` on Windows, but also respects the ``XDG_CONFIG_HOME`` environment
@@ -30,12 +34,14 @@ def getConfigPath():
 
 _config = None
 
+
 def init():
     """Initialize `_config` from the config file."""
     global _config
     _config = configparser.ConfigParser()
     _config.read(getConfigPath())
 
+
 def ensureInit(func):
     """Decorator that calls :func:`init()` if necessary."""
     def newFunc(*args, **kwargs):
@@ -45,6 +51,7 @@ def ensureInit(func):
         return func(*args, **kwargs)
     return newFunc
 
+
 @ensureInit
 def setDefaultDatabase(db):
     """Sets the default database."""
@@ -55,6 +62,7 @@ def setDefaultDatabase(db):
             del _config[section]['default']
     _config[db.directory]['default'] = 'yes'
 
+
 @ensureInit
 def getDefaultDatabase():
     """Return the default database, or None if the config file is empty."""
@@ -68,6 +76,7 @@ def getDefaultDatabase():
     except:
         return None
 
+
 @ensureInit
 def setAuthInformation(db):
     """Set username / password information for the given database."""
@@ -76,6 +85,7 @@ def setAuthInformation(db):
     _config[db.directory]['username'] = db.vcs.username
     _config[db.directory]['password'] = db.vcs.password
 
+
 @ensureInit
 def getAuthInformation(db):
     """Return a pair of `(username, password)` for the given database, or ``None`` if it is not
@@ -86,6 +96,7 @@ def getAuthInformation(db):
     except KeyError:
         return None
 
+
 @atexit.register
 def save():
     """Store the current configuration to disk."""
