@@ -14,7 +14,7 @@ import configparser, io, os, subprocess
 from collections import OrderedDict
 from os.path import join, exists, relpath
 
-from pkg_resources import  resource_string, resource_filename
+from pkg_resources import  resource_string, resource_filename, get_distribution
 
 from bibtexvcs.bibfile import BibFile, MacroReference
 from bibtexvcs.vcs import VCSInterface
@@ -84,8 +84,12 @@ class Database:
 
     def reload(self):
         parser = configparser.ConfigParser()
-        with io.open(self.configPath, encoding='UTF-8') as f:
-            confFile = f.read()
+        try:
+            with io.open(self.configPath, encoding='UTF-8') as f:
+                confFile = f.read()
+        except IOError:
+            raise DatabaseFormatError('Not a valid BibTeX VCS directory: '
+                                      'Configuration file bibtexvcs.conf not found.')
         # workaround because ConfigParser does not support sectionless entries
         try:
             parser.read_string("[root]\n" + confFile)
@@ -153,7 +157,7 @@ class Database:
     def strval(self, value):
         if isinstance(value, MacroReference):
             if value.name in self.bibfile.macroDefinitions:
-                return self.bibfile.macroDefinitions[value.macro]
+                return self.bibfile.macroDefinitions[value.name]
             if value.name in self.journals:
                 return self.journals[value.name].full
         return str(value)
@@ -192,7 +196,6 @@ class Database:
         else:
             cmdline += ['--primp', resource_filename(__name__, 'defaultJabref.prefs')]
         cmdline.append(os.curdir + os.sep + self.bibfileName)
-        print(cmdline)
         try:
             return subprocess.Popen(cmdline, shell=shell, cwd=self.directory)
         except FileNotFoundError as fnf:
@@ -229,9 +232,11 @@ class Database:
             templateString = resource_string(__name__, 'defaultTemplate.html').decode('UTF-8')
         template = env.from_string(templateString)
         revision = self.vcs.revision()
+        import locale
+        locale.setlocale(locale.LC_ALL, '')
         now = datetime.datetime.now().strftime('%c')
-        return template.render(database=self, docDir=docDir, revision=revision, now=now)
-
+        version = get_distribution('bibtexvcs').version
+        return template.render(database=self, docDir=docDir, version=version, revision=revision, now=now)
 
 
 class Journal:
